//
//  SNGPayEachTimeVC.swift
//  Nextgen Dev
//
//  Created by Vu on 03/02/2021.
//  Copyright © 2021 Chinh.nd. All rights reserved.
//

import UIKit

class SNGPayEachTimeDetailVC: SNGBaseViewController {
    @IBOutlet weak var header: SNGHead!
    @IBOutlet weak var billTypeView: SNGSelectionView!
    @IBOutlet weak var providerView: SNGSelectionView!
    @IBOutlet weak var lbCustomerID: SNGLabel!
    @IBOutlet weak var btnBillQueries: SNGButton!
    @IBOutlet weak var lbCustomerName: SNGLabel!
    @IBOutlet weak var lbAmount: SNGLabel!
    @IBOutlet weak var tfAddress: UITextField!
    @IBOutlet weak var cellFromAccount: SNGTransferAccountCell!
    @IBOutlet weak var tfDescription: UITextField!
    @IBOutlet weak var lbLength: SNGLabel!
    @IBOutlet weak var lbDate: SNGLabel!
    @IBOutlet weak var btnSaveTemplate: UIButton!
    @IBOutlet weak var btnPriority: UIButton!
    
   
    let validator = Validator()
    var listAccount: [SNGAccountModel] = []
    var BillType: SNGBillTypeModel?
    var Providers: SNGProviderModel?
    var BillId: String = ""
    var BillDetail: SNGBillingInforModel?
    var city: String = ""
    var selectedAcountFrom: Int = -1
    let formatter = DateFormatter()
    var isPriority: Bool = false
    var isSaveTemplate: Bool = false
    override func viewDidLoad() {
        super.viewDidLoad()
        configView()
        loadData()
    }
    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(true)
       
    }
    
    func configView() {
        header.selectBack = {
            self.backViewController()
        }
        header.lbTitle.text = "payment.header.payeachtime".localized()
        btnBillQueries.setDisable()
        cellFromAccount.title.text = "transfer.label.detail.fromAcc".localized()
        cellFromAccount.placeHolder.text = "transfer.owner.dropdown.accountfrom.placeholder".localized()
        cellFromAccount.selection = false
        cellFromAccount.onTab = selectAccountFrom
        formatter.dateFormat = "dd/MM/yyyy" //format date
        let stringdate = formatter.string(from: Date()) //convert date to string
        self.lbDate.text = stringdate
    }
    
    
    func loadData() {
        self.billTypeView.txtSelectedValue.text = self.BillType!.addNameVI
        self.providerView.txtSelectedValue.text = self.Providers!.name_vi
        self.lbCustomerID.text = self.BillId
        self.lbCustomerName.text = self.BillDetail!.billingName
        self.lbAmount.text = "\(self.BillDetail!.amount.toCurrencyString("VND")) VND"
        self.tfAddress.text = self.city

    }
    @IBAction func onTxtDesDidEnd(_ sender: UITextField) {
        tfDescription.text = sender.text?.trim()
        lbLength.text =  "\(tfDescription.text!.utf16.count)/140"
    }
    
    
    func validateForm(){
        if self.selectedAcountFrom != -1 {
            self.btnBillQueries.setEnable()
        }
    }
    
    func selectAccountFrom(){
        self.closeKeyBoard()
        let bottomsheet =  SNGPopupSelectionBottom()
        bottomsheet.headerTitle = "transfer.label.detail.fromAcc".localized()
        bottomsheet.data = listAccount
        bottomsheet.selectedIndex = selectedAcountFrom
        bottomsheet.onSelectedIndex = onSelectedAccountFrom
        bottomsheet.columnType = "TransferAccountViewCell"
        bottomsheet.modalPresentationStyle = .overCurrentContext
        bottomsheet.modalTransitionStyle = .crossDissolve
        self.present(bottomsheet, animated: true, completion: nil)
    }
    
    func onSelectedAccountFrom(index: Int) {
        self.selectedAcountFrom = index
        self.cellFromAccount.setData(listAccount[index])
        self.btnBillQueries.setEnable()
    }
    @IBAction func onSaveTemplate(_ sender: Any) {
        isSaveTemplate = !isSaveTemplate
        if isSaveTemplate {
            btnSaveTemplate.backgroundColor = UIColor.colorFromHex("#78D700")
            btnSaveTemplate.setImage(UIImage(named: "iconPopupSuccess"), for: .normal)
            btnSaveTemplate.layer.borderWidth = 0
        } else {
            btnSaveTemplate.backgroundColor = .clear
            btnSaveTemplate.setImage(nil, for: .normal)
            btnSaveTemplate.layer.borderWidth = 1
        }
    }
    @IBAction func onChangePriority(_ sender: Any) {
        isPriority = !isPriority
        if isPriority {
            btnPriority.backgroundColor = UIColor.colorFromHex("#78D700")
            btnPriority.setImage(UIImage(named: "iconPopupSuccess"), for: .normal)
            btnPriority.layer.borderWidth = 0
        } else {
            btnPriority.backgroundColor = .clear
            btnPriority.setImage(nil, for: .normal)
            btnPriority.layer.borderWidth = 1
        }
    }
    
    @IBAction func onSelectPay(_ sender: Any) {
        let storyboard = UIStoryboard(name: "SNGPayEachTimeConfirm", bundle: nil)
        let viewController = storyboard.instantiateViewController(withIdentifier: "SNGPayEachTimeConfirm") as! SNGPayEachTimeConfirmVC
        viewController.account = self.listAccount[self.selectedAcountFrom]
        let data = SNGBillTransactionModel()
        data.address = self.tfAddress.text!
        
        if let provider =  self.Providers {
            data.providerId = provider.providerID
            data.providerName = provider.name_gb
        }
        if let billType = self.BillType {
            data.serviceId = billType.serviceID
            data.serviceName = billType.addNameVI
        }
        
        data.amount = self.lbAmount.text!
        data.fromAccount = self.listAccount[self.selectedAcountFrom].accountID
        data.content = self.tfDescription.text!
        data.priority = self.isPriority
        data.billNo = self.BillDetail!.billNo
        data.benName = self.BillDetail!.billingName
        data.transDate = self.lbDate.text!
        viewController.type = .EACHTIME
        viewController.transactionData = data
        navigationController?.pushViewController(viewController, animated: true)
    }
    
}

extension SNGPayEachTimeDetailVC: UITextFieldDelegate {
    func changeText(_ textField: UITextField, shouldChangeCharactersIn range: NSRange, replacementString string: String){
        if string.count != 1 {
            textField.text = (textField.text! as NSString).replacingCharacters(in:range, with: string.trim())
            DispatchQueue.main.async(execute: {
                let newPosition = textField.position(from:textField.beginningOfDocument, offset:range.location+string.trim().count)
                if newPosition != nil {
                    textField.selectedTextRange = textField.textRange(from: newPosition!, to: newPosition!)
                }
            })
        } else {
            textField.text = (textField.text! as NSString).replacingCharacters(in:range, with: string)
            DispatchQueue.main.async(execute: {
                let newPosition = textField.position(from: textField.beginningOfDocument, offset: range.location + string.count)
                if newPosition != nil {
                    textField.selectedTextRange = textField.textRange(from: newPosition!, to: newPosition!)
                }
            })
        }
        
    }
    
    func textField(_ textField: UITextField, shouldChangeCharactersIn range: NSRange, replacementString string: String) -> Bool {
            guard let textFieldText = textField.text, let rangeOfTextToReplace = Range(range, in: textFieldText) else {
                return false
            }
            var string = string
            if string.count > 140 {
                let otherRange = string.index(string.startIndex, offsetBy: 140 - (textField.text?.count ?? 0))..<string.endIndex
                string.removeSubrange(otherRange)
            }
            let substringToReplace = textFieldText[rangeOfTextToReplace]
            let count = textFieldText.count - substringToReplace.count + string.count
            let trim = textField.text! + string
                if string != "" {
                    if count <= 210 && validator.validate(text: trim, with: [.contentBillDescription]) {
                        changeText(textField, shouldChangeCharactersIn: range, replacementString: string)
                        self.lbLength.text =  "\(trim.utf16.count)/210"
                    }
                    return false
                }
                self.lbLength.text =  "\(trim.utf16.count - 1)/210"

            validateForm()
            return true
    }
}


